@@ -40,9 +40,6 @@ describe 'tripleo::profile::base::octavia::api' do
       class { 'octavia::db::mysql':
         password => 'some_password'
       }
-      class { 'octavia::keystone::authtoken':
-        password => 'some_password'
-      }
 eos
     end
 
@@ -117,9 +114,6 @@ eos
       end
 
       it 'should should set provider drivers and ovn nb connection' do
-        is_expected.to contain_class('octavia::api').with(
-          :provider_drivers =>
-            'amphora: The Octavia Amphora driver.,octavia: Deprecated alias of the Octavia Amphora driver.,ovn: Octavia OVN driver.')
         is_expected.to contain_class('octavia::api').with(:ovn_nb_connection => 'tcp:127.0.0.1:6641')
       end
     end
